@@ -113,3 +113,39 @@ void ItemFakeVimTests::search()
         << ":gg/[EH]" << "ENTER" << ":r_nr_" << "F2", "");
     RUN(args << "read" << "0", "ABC\nD_F\nG_I");
 }
+
+void ItemFakeVimTests::incDecNumbers()
+{
+    const QString tab1 = testTab(1);
+    const Args args = Args() << "tab" << tab1;
+
+    RUN(args << "add" << " 0", "");
+    RUN(args << "edit" << "0", "");
+    RUN(args << "keys" << FAKEVIM_CTRL "+a" << "F2", "");
+    RUN(args << "read" << "0", " 1");
+
+    RUN(args << "add" << " -1", "");
+    RUN(args << "edit" << "0", "");
+    RUN(args << "keys" << FAKEVIM_CTRL "+a" << "F2", "");
+    RUN(args << "read" << "0", " 0");
+
+    RUN(args << "add" << " 0xff", "");
+    RUN(args << "edit" << "0", "");
+    RUN(args << "keys" << FAKEVIM_CTRL "+a" << "F2", "");
+    RUN(args << "read" << "0", " 0x100");
+
+    RUN(args << "add" << "9 9 9", "");
+    RUN(args << "edit" << "0", "");
+    RUN(args << "keys" << "l" << FAKEVIM_CTRL "+a" << "l" << FAKEVIM_CTRL "+a" << "F2", "");
+    RUN(args << "read" << "0", "9 10 10");
+
+    RUN(args << "add" << "-1 -1 -1", "");
+    RUN(args << "edit" << "0", "");
+    RUN(args << "keys" << ":ll" << "2" << FAKEVIM_CTRL "+a" << "l" << "3" << FAKEVIM_CTRL "+a" << "F2", "");
+    RUN(args << "read" << "0", "-1 1 2");
+
+    RUN(args << "add" << "1 1 1", "");
+    RUN(args << "edit" << "0", "");
+    RUN(args << "keys" << "l" << "2" << FAKEVIM_CTRL "+x" << "l" << "3" << FAKEVIM_CTRL "+x" << "F2", "");
+    RUN(args << "read" << "0", "1 -1 -2");
+}
