@@ -34,7 +34,7 @@ namespace Ui {
 class ItemImageSettings;
 }
 
-class ItemImage : public QLabel, public ItemWidget
+class ItemImage final : public QLabel, public ItemWidget
 {
     Q_OBJECT
 
@@ -42,13 +42,8 @@ public:
     ItemImage(
             const QPixmap &pix,
             const QByteArray &animationData, const QByteArray &animationFormat,
-            const QString &imageEditor, const QString &svgEditor,
             QWidget *parent);
 
-    QWidget *createEditor(QWidget *) const override { return nullptr; }
-
-    QObject *createExternalEditor(const QModelIndex &index, QWidget *parent) const override;
-
     void updateSize(QSize maximumSize, int idealWidth) override;
 
     void setCurrent(bool current) override;
@@ -62,15 +57,13 @@ private:
     void startAnimation();
     void stopAnimation();
 
-    QString m_editor;
-    QString m_svgEditor;
     QPixmap m_pixmap;
     QByteArray m_animationData;
     QByteArray m_animationFormat;
     QMovie *m_animation;
 };
 
-class ItemImageLoader : public QObject, public ItemLoaderInterface
+class ItemImageLoader final : public QObject, public ItemLoaderInterface
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID COPYQ_PLUGIN_ITEM_LOADER_ID)
@@ -98,6 +91,8 @@ public:
 
     QWidget *createSettingsWidget(QWidget *parent) override;
 
+    QObject *createExternalEditor(const QModelIndex &index, const QVariantMap &data, QWidget *parent) const override;
+
 private:
     QVariantMap m_settings;
     std::unique_ptr<Ui::ItemImageSettings> ui;
