@@ -25,6 +25,7 @@
 #include "common/textdata.h"
 #include "gui/iconfont.h"
 #include "gui/iconwidget.h"
+#include "gui/pixelratio.h"
 
 #include <QBoxLayout>
 #include <QLabel>
@@ -55,7 +56,7 @@ QWidget *createIconWidget(const QByteArray &icon, QWidget *parent)
     if (!icon.isEmpty()) {
         QPixmap p;
         if (p.loadFromData(icon)) {
-            const auto ratio = parent->devicePixelRatio();
+            const auto ratio = pixelRatio(parent);
             p.setDevicePixelRatio(ratio);
 
             const int side = ratio * (iconFontSizePixels() + 2);
@@ -161,14 +162,14 @@ void ItemNotes::setCurrent(bool current)
         m_timerShowToolTip->stop();
 }
 
-void ItemNotes::highlight(const QRegExp &re, const QFont &highlightFont, const QPalette &highlightPalette)
+void ItemNotes::highlight(const QRegularExpression &re, const QFont &highlightFont, const QPalette &highlightPalette)
 {
     ItemWidgetWrapper::highlight(re, highlightFont, highlightPalette);
 
     if (m_notes != nullptr) {
         QList<QTextEdit::ExtraSelection> selections;
 
-        if ( !re.isEmpty() ) {
+        if ( re.isValid() && !re.pattern().isEmpty() ) {
             QTextEdit::ExtraSelection selection;
             selection.format.setBackground( highlightPalette.base() );
             selection.format.setForeground( highlightPalette.text() );
@@ -315,8 +316,8 @@ ItemWidget *ItemNotesLoader::transform(ItemWidget *itemWidget, const QVariantMap
         m_settings["show_tooltip"].toBool() );
 }
 
-bool ItemNotesLoader::matches(const QModelIndex &index, const QRegExp &re) const
+bool ItemNotesLoader::matches(const QModelIndex &index, const QRegularExpression &re) const
 {
     const QString text = index.data(contentType::notes).toString();
-    return re.indexIn(text) != -1;
+    return text.contains(re);
 }
