@@ -49,7 +49,7 @@ public:
     void setCurrent(bool current) override;
 
 protected:
-    void highlight(const QRegExp &re, const QFont &highlightFont,
+    void highlight(const QRegularExpression &re, const QFont &highlightFont,
                            const QPalette &highlightPalette) override;
 
     void updateSize(QSize maximumSize, int idealWidth) override;
@@ -94,7 +94,7 @@ public:
 
     ItemWidget *transform(ItemWidget *itemWidget, const QVariantMap &data) override;
 
-    bool matches(const QModelIndex &index, const QRegExp &re) const override;
+    bool matches(const QModelIndex &index, const QRegularExpression &re) const override;
 
 private:
     QVariantMap m_settings;
