@@ -22,9 +22,11 @@
 
 #include "common/command.h"
 #include "common/contenttype.h"
+#include "common/regexp.h"
 #include "common/textdata.h"
 #include "gui/iconfont.h"
 #include "gui/iconselectbutton.h"
+#include "gui/pixelratio.h"
 
 #ifdef HAS_TESTS
 #   include "tests/itemtagstests.h"
@@ -268,8 +270,8 @@ ItemTags::Tag findMatchingTag(const QString &tagText, const ItemTags::Tags &tags
             if (tag.name == tagText)
                 return tag;
         } else {
-            const QRegExp re(tag.match);
-            if ( re.exactMatch(tagText) )
+            const auto re = anchoredRegExp(tag.match);
+            if (tagText.contains(re))
                 return tag;
         }
     }
@@ -312,7 +314,7 @@ private:
             QWidget tagWidget;
             initTagWidget(&tagWidget, tag, smallerFont(QFont()));
 
-            const auto ratio = tagWidget.devicePixelRatio();
+            const auto ratio = pixelRatio(&tagWidget);
             m_pixmap = QPixmap( tagWidget.sizeHint() * ratio );
             m_pixmap.setDevicePixelRatio(ratio);
 
@@ -653,12 +655,12 @@ ItemWidget *ItemTagsLoader::transform(ItemWidget *itemWidget, const QVariantMap
     return new ItemTags(itemWidget, tags);
 }
 
-bool ItemTagsLoader::matches(const QModelIndex &index, const QRegExp &re) const
+bool ItemTagsLoader::matches(const QModelIndex &index, const QRegularExpression &re) const
 {
     const QByteArray tagsData =
             index.data(contentType::data).toMap().value(mimeTags).toByteArray();
     const auto tags = getTextData(tagsData);
-    return re.indexIn(tags) != -1;
+    return tags.contains(re);
 }
 
 QObject *ItemTagsLoader::tests(const TestInterfacePtr &test) const
@@ -740,7 +742,7 @@ void ItemTagsLoader::onColorButtonClicked()
 
     const QColor color = button->property(propertyColor).value<QColor>();
     QColorDialog dialog(button->window());
-    dialog.setOptions(dialog.options() | QColorDialog::ShowAlphaChannel);
+    dialog.setOptions(dialog.options() | QColorDialog::ShowAlphaChannel | QColorDialog::DontUseNativeDialog);
     dialog.setCurrentColor(color);
 
     if ( dialog.exec() == QDialog::Accepted )
@@ -806,7 +808,7 @@ ItemTagsLoader::Tags ItemTagsLoader::toTags(const QStringList &tagList)
             if (tag.match.isEmpty()) {
                 tag.name = tagName;
             } else {
-                const QRegExp re(tag.match);
+                const QRegularExpression re(tag.match);
                 tag.name = QString(tagName).replace(re, tag.name);
             }
         } else {
