@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -156,18 +156,12 @@ ClientSocket::~ClientSocket()
     close();
 }
 
-void ClientSocket::waitForReadyRead()
-{
-    if (m_socket)
-        m_socket->waitForReadyRead(2000);
-}
-
-void ClientSocket::start()
+bool ClientSocket::start()
 {
     if ( !m_socket || !m_socket->waitForConnected(4000) )
     {
         emit connectionFailed(id());
-        return;
+        return false;
     }
 
     SOCKET_LOG("Creating socket.");
@@ -182,6 +176,8 @@ void ClientSocket::start()
     onStateChanged(m_socket->state());
 
     onReadyRead();
+
+    return true;
 }
 
 void ClientSocket::sendMessage(const QByteArray &message, int messageCode)
@@ -213,11 +209,6 @@ void ClientSocket::close()
     }
 }
 
-bool ClientSocket::isClosed() const
-{
-    return m_closed;
-}
-
 void ClientSocket::onReadyRead()
 {
     if (!m_socket) {
