@@ -38,6 +38,7 @@
 #include <QObject>
 #include <QPoint>
 #include <QProcess>
+#include <QRegularExpression>
 #include <QTextCodec>
 #include <QThread>
 #include <QUrl>
@@ -118,8 +119,9 @@ public:
         QElapsedTimer m_elapsed;
     };
 
-    explicit ClipboardDataGuard(const QMimeData &data)
+    explicit ClipboardDataGuard(const QMimeData &data, bool *abortCloning = nullptr)
         : m_dataGuard(&data)
+        , m_abort(abortCloning)
     {
         m_timerExpire.start();
     }
@@ -181,6 +183,9 @@ public:
 private:
     bool refresh()
     {
+        if (m_abort && *m_abort)
+            return false;
+
         if (m_dataGuard.isNull())
             return false;
 
@@ -199,6 +204,7 @@ private:
 
     QPointer<const QMimeData> m_dataGuard;
     QElapsedTimer m_timerExpire;
+    bool *m_abort = nullptr;
 
 #ifdef COPYQ_WS_X11
     WakeUpThread m_wakeUpThread;
@@ -332,9 +338,9 @@ const QMimeData *clipboardData(ClipboardMode mode)
     return data;
 }
 
-QVariantMap cloneData(const QMimeData &rawData, QStringList formats)
+QVariantMap cloneData(const QMimeData &rawData, QStringList formats, bool *abortCloning)
 {
-    ClipboardDataGuard data(rawData);
+    ClipboardDataGuard data(rawData, abortCloning);
 
     const auto internalMimeTypes = {mimeOwner, mimeWindowTitle, mimeItemNotes, mimeHidden};
 
@@ -442,7 +448,7 @@ QString elideText(const QString &text, const QFont &font, const QString &format,
     QStringList lines = text.split('\n');
 
     // Ignore empty lines at beginning.
-    static const QRegExp reNonEmpty(".*\\S.*");
+    static const QRegularExpression reNonEmpty(".*\\S.*");
     const int firstLine = qMax(0, lines.indexOf(reNonEmpty));
     const int lastLine = qMax(0, lines.lastIndexOf(reNonEmpty, firstLine + maxLines - 1));
 
@@ -457,7 +463,11 @@ QString elideText(const QString &text, const QFont &font, const QString &format,
     lines = lines.mid(firstLine, lastLine - firstLine + 1);
 
     QFontMetrics fm(font);
+#if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
+    const int formatWidth = format.isEmpty() ? 0 : fm.horizontalAdvance(format.arg(QString()));
+#else
     const int formatWidth = format.isEmpty() ? 0 : fm.width(format.arg(QString()));
+#endif
 
     // Remove redundant spaces from single line text.
     if (lines.size() == 1)
@@ -465,7 +475,7 @@ QString elideText(const QString &text, const QFont &font, const QString &format,
 
     // Find common indentation.
     int commonIndent = lines.value(0).size();
-    static const QRegExp reNonSpace("\\S");
+    static const QRegularExpression reNonSpace("\\S");
     for (const auto &line : lines) {
         const int lineIndent = line.indexOf(reNonSpace);
         if (lineIndent != -1 && lineIndent < commonIndent) {
