@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -45,7 +45,7 @@ copySelection(dateTime)
 paste()
 )";
 
-class AddCommandDialog
+class AddCommandDialog final
 {
     Q_DECLARE_TR_FUNCTIONS(AddCommandDialog)
 };
