@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -32,7 +32,7 @@ class QLocalServer;
 using ClientSocketPtr = std::shared_ptr<ClientSocket>;
 Q_DECLARE_METATYPE(ClientSocketPtr)
 
-class Server : public QObject
+class Server final : public QObject
 {
     Q_OBJECT
 public:
