@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -27,7 +27,7 @@
  *
  * Use this to get ini as data instead of saving to a file.
  */
-class TemporarySettings
+class TemporarySettings final
 {
 public:
     /// Creates temporary settings file.
