@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -26,10 +26,8 @@ namespace Ui {
     class AboutDialog;
 }
 
-class AboutDialog : public QDialog
+class AboutDialog final : public QDialog
 {
-    Q_OBJECT
-
 public:
     explicit AboutDialog(QWidget *parent = nullptr);
     ~AboutDialog();
