@@ -26,7 +26,6 @@
 #include "common/mimetypes.h"
 #include "common/textdata.h"
 #include "item/serialize.h"
-#include "gui/windowgeometryguard.h"
 
 #include <QAbstractButton>
 #include <QFile>
@@ -58,7 +57,7 @@ QString commandToLabel(const QString &command)
 {
     QString label = command.size() > 48 ? command.left(48) + "..." : command;
     label.replace('\n', " ");
-    label.replace(QRegExp("\\s\\+"), " ");
+    label.replace(QRegularExpression("\\s\\+"), " ");
     return label;
 }
 
@@ -90,8 +89,6 @@ ActionDialog::ActionDialog(QWidget *parent)
     onComboBoxInputFormatCurrentIndexChanged(QString());
     onComboBoxOutputFormatEditTextchanged(QString());
     loadSettings();
-
-    WindowGeometryGuard::create(this);
 }
 
 ActionDialog::~ActionDialog()
@@ -304,8 +301,8 @@ void ActionDialog::acceptCommand()
 
     auto re = command.re;
     const QString text = getTextData(m_data);
-    re.indexIn(text);
-    auto capturedTexts = re.capturedTexts();
+    const auto m = re.match(text);
+    auto capturedTexts = m.capturedTexts();
     if ( capturedTexts.isEmpty() )
         capturedTexts.append(QString());
     capturedTexts[0] = text;
