@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -21,21 +21,22 @@
 
 #include "common/appconfig.h"
 #include "common/action.h"
+#include "common/actiontablemodel.h"
 #include "common/common.h"
 #include "common/contenttype.h"
 #include "common/display.h"
 #include "common/log.h"
 #include "common/mimetypes.h"
 #include "common/textdata.h"
+#include "gui/actionhandlerdialog.h"
 #include "gui/icons.h"
 #include "gui/notification.h"
-#include "gui/processmanagerdialog.h"
+#include "gui/notificationdaemon.h"
 #include "gui/clipboardbrowser.h"
 #include "gui/mainwindow.h"
 #include "item/serialize.h"
 
-#include <QDateTime>
-#include <QModelIndex>
+#include <QDialog>
 
 #include <cmath>
 
@@ -50,24 +51,30 @@ QString actionDescription(const Action &action)
     return action.commandLine();
 }
 
-} // namespace
-
-ActionHandler::ActionHandler(MainWindow *mainWindow)
-    : QObject(mainWindow)
-    , m_wnd(mainWindow)
-    , m_activeActionDialog(new ProcessManagerDialog(mainWindow))
+uint maxRowCount()
 {
-    Q_ASSERT(mainWindow);
+    return AppConfig().option<Config::max_process_manager_rows>();
 }
 
-void ActionHandler::showProcessManagerDialog()
+} // namespace
+
+ActionHandler::ActionHandler(NotificationDaemon *notificationDaemon, QWidget *parent)
+    : QObject(parent)
+    , m_notificationDaemon(notificationDaemon)
+    , m_actionModel(new ActionTableModel(maxRowCount(), parent))
 {
-    m_activeActionDialog->show();
+}
+
+void ActionHandler::showProcessManagerDialog(QWidget *parent)
+{
+    auto dialog = new ActionHandlerDialog(this, m_actionModel, parent);
+    dialog->setAttribute(Qt::WA_DeleteOnClose, true);
+    dialog->show();
 }
 
 void ActionHandler::addFinishedAction(const QString &name)
 {
-    m_activeActionDialog->actionFinished(name);
+    m_actionModel->actionFinished(name);
 }
 
 QVariantMap ActionHandler::actionData(int id) const
@@ -99,23 +106,29 @@ void ActionHandler::action(Action *action)
 {
     action->setParent(this);
 
-    const auto id = ++m_lastActionId;
-    action->setId(id);
-    m_actions.insert(id, action);
-
     connect( action, &Action::actionStarted,
              this, &ActionHandler::actionStarted );
     connect( action, &Action::actionFinished,
              this, &ActionHandler::closeAction );
 
-    m_activeActionDialog->actionAboutToStart(action);
+    const int id = m_actionModel->actionAboutToStart(action);
+    action->setId(id);
+    m_actions.insert(id, action);
+
     COPYQ_LOG( QString("Executing: %1").arg(actionDescription(*action)) );
     action->start();
 }
 
+void ActionHandler::terminateAction(int id)
+{
+    Action *action = m_actions.value(id);
+    if (action)
+        action->terminate();
+}
+
 void ActionHandler::actionStarted(Action *action)
 {
-    m_activeActionDialog->actionStarted(action);
+    m_actionModel->actionStarted(action);
     emit runningActionsCountChanged();
 }
 
@@ -139,7 +152,7 @@ void ActionHandler::closeAction(Action *action)
         showActionErrors(action, msg, IconTimesCircle);
     }
 
-    m_activeActionDialog->actionFinished(action);
+    m_actionModel->actionFinished(action);
     Q_ASSERT(runningActionCount() >= 0);
 
     emit runningActionsCountChanged();
@@ -149,8 +162,9 @@ void ActionHandler::closeAction(Action *action)
 
 void ActionHandler::showActionErrors(Action *action, const QString &message, ushort icon)
 {
+    m_actionModel->actionFailed(action, message);
     const auto notificationId = qHash(action->commandLine()) ^ qHash(message);
-    auto notification = m_wnd->createNotification( QString::number(notificationId) );
+    auto notification = m_notificationDaemon->createNotification( QString::number(notificationId) );
     if ( notification->isVisible() )
         return;
 
