@@ -29,6 +29,7 @@
 #include "gui/clipboarddialog.h"
 #include "gui/iconfactory.h"
 #include "gui/icons.h"
+#include "gui/pixelratio.h"
 #include "gui/theme.h"
 #include "item/itemeditor.h"
 #include "item/itemeditorwidget.h"
@@ -356,13 +357,17 @@ bool ClipboardBrowser::eventFilter(QObject *obj, QEvent *event)
 
 bool ClipboardBrowser::isFiltered(int row) const
 {
-    if ( d.searchExpression().isEmpty() || !m_itemSaver)
+    const auto re = d.searchExpression();
+    if ( re.pattern().isEmpty() || !m_itemSaver)
         return false;
 
+    if ( !re.isValid() )
+        return true;
+
     const QModelIndex ind = m.index(row);
     return m_filterRow != row
             && m_sharedData->itemFactory
-            && !m_sharedData->itemFactory->matches( ind, d.searchExpression() );
+            && !m_sharedData->itemFactory->matches(ind, re);
 }
 
 QVariantMap ClipboardBrowser::itemData(const QModelIndex &index) const
@@ -451,13 +456,17 @@ void ClipboardBrowser::setEditorWidget(ItemEditorWidget *editor, bool changeClip
         } else {
             setFocus();
             maybeEmitEditingFinished();
-            if ( !d.searchExpression().isEmpty() )
-                emit searchRequest();
+            const auto oldSearch = d.searchExpression().pattern();
+            if ( oldSearch.isEmpty() )
+                emit searchHideRequest();
+            else
+                emit searchShowRequest(d.searchExpression().pattern());
         }
 
         emit internalEditorStateChanged(this);
     }
 
+    clearFocus();
     setFocusProxy(m_editor);
     setFocus();
 
@@ -851,8 +860,8 @@ QPixmap ClipboardBrowser::renderItemPreview(const QModelIndexList &indexes, int
     if (h == 0)
         return QPixmap();
 
-    const auto ratio = devicePixelRatio();
-    const auto frameLineWidth = 2 * ratio;
+    const auto ratio = pixelRatio(this);
+    const int frameLineWidth = std::ceil(2 * ratio);
 
     const auto height = qMin(maxHeight, h + s + 2 * frameLineWidth);
     const auto width = qMin(maxWidth, viewport()->contentsRect().width() + 2 * frameLineWidth);
@@ -1285,10 +1294,7 @@ bool ClipboardBrowser::openEditor(const QModelIndex &index)
     if ( !isLoaded() )
         return false;
 
-    auto data = m_sharedData->itemFactory->data(index);
-    if (m_itemSaver)
-        data = m_itemSaver->copyItem(m, data);
-
+    const auto data = m_sharedData->itemFactory->data(index);
     if ( data.isEmpty() )
         return false;
 
@@ -1315,18 +1321,6 @@ void ClipboardBrowser::addItems(const QStringList &items)
     }
 }
 
-void ClipboardBrowser::showItemContent()
-{
-    const QModelIndex current = currentIndex();
-    if ( current.isValid() ) {
-        std::unique_ptr<ClipboardDialog> clipboardDialog(
-                    new ClipboardDialog(currentIndex(), &m, this) );
-        clipboardDialog->setAttribute(Qt::WA_DeleteOnClose, true);
-        clipboardDialog->show();
-        clipboardDialog.release();
-    }
-}
-
 void ClipboardBrowser::editNotes()
 {
     QModelIndex ind = currentIndex();
@@ -1352,7 +1346,7 @@ void ClipboardBrowser::itemModified(const QByteArray &bytes, const QString &mime
     }
 }
 
-void ClipboardBrowser::filterItems(const QRegExp &re)
+void ClipboardBrowser::filterItems(const QRegularExpression &re)
 {
     // Search in editor if open.
     if ( isInternalEditorOpen() ) {
@@ -1361,7 +1355,8 @@ void ClipboardBrowser::filterItems(const QRegExp &re)
     }
 
     // Do nothing if same regexp was already set or both are empty (don't compare regexp options).
-    if ( (d.searchExpression().isEmpty() && re.isEmpty()) || d.searchExpression() == re )
+    const auto oldRe = d.searchExpression();
+    if ( (oldRe.pattern().isEmpty() && re.pattern().isEmpty()) || oldRe == re )
         return;
 
     d.setSearch(re);
@@ -1375,7 +1370,7 @@ void ClipboardBrowser::filterItems(const QRegExp &re)
 
     int row = 0;
 
-    if ( re.isEmpty() ) {
+    if ( re.pattern().isEmpty() ) {
         for ( ; row < length(); ++row )
             hideFiltered(row);
 
@@ -1419,7 +1414,7 @@ void ClipboardBrowser::editNew(const QString &text, bool changeClipboard)
         return;
 
     emit searchHideRequest();
-    filterItems(QRegExp());
+    filterItems(QRegularExpression());
     if ( add(text) )
         editItem(currentIndex(), false, changeClipboard);
 }
@@ -1861,13 +1856,13 @@ QWidget *ClipboardBrowser::currentItemPreview(QWidget *parent)
 void ClipboardBrowser::findNext()
 {
     if (isInternalEditorOpen())
-        m_editor->findNext(d.searchExpression());
+        m_editor->findNext();
 }
 
 void ClipboardBrowser::findPrevious()
 {
     if (isInternalEditorOpen())
-        m_editor->findPrevious(d.searchExpression());
+        m_editor->findPrevious();
 }
 
 bool ClipboardBrowser::isInternalEditorOpen() const
