@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -25,7 +25,7 @@
 #include <QAction>
 #include <QPointer>
 
-class CommandAction : public QAction
+class CommandAction final : public QAction
 {
     Q_OBJECT
 public:
