@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -31,7 +31,7 @@ class CommandDialog;
 
 class QAbstractButton;
 
-class CommandDialog : public QDialog
+class CommandDialog final : public QDialog
 {
     Q_OBJECT
 
