@@ -30,6 +30,7 @@
 #include "gui/clipboardbrowser.h"
 #include "gui/clipboardbrowsershared.h"
 #include "gui/iconfont.h"
+#include "gui/pixelratio.h"
 #include "gui/theme.h"
 #include "item/itemeditor.h"
 #include "item/itemdelegate.h"
@@ -300,6 +301,7 @@ void ConfigTabAppearance::fontButtonClicked(QObject *button)
 {
     QFont font = m_theme.themeFontFromString( button->property("VALUE").toString() );
     QFontDialog dialog(font, this);
+    dialog.setOptions(dialog.options() | QFontDialog::DontUseNativeDialog);
     if ( dialog.exec() == QDialog::Accepted ) {
         font = dialog.selectedFont();
         button->setProperty( "VALUE", font.toString() );
@@ -312,7 +314,7 @@ void ConfigTabAppearance::colorButtonClicked(QObject *button)
 {
     QColor color = evalColor( button->property("VALUE").toString(), m_theme );
     QColorDialog dialog(this);
-    dialog.setOptions(dialog.options() | QColorDialog::ShowAlphaChannel);
+    dialog.setOptions(dialog.options() | QColorDialog::ShowAlphaChannel | QColorDialog::DontUseNativeDialog);
     dialog.setCurrentColor(color);
 
     if ( dialog.exec() == QDialog::Accepted ) {
@@ -339,7 +341,7 @@ void ConfigTabAppearance::updateColorButtons()
     QPixmap pix(iconSize);
 
     QList<QPushButton *> buttons =
-            ui->scrollAreaTheme->findChildren<QPushButton *>(QRegExp("^pushButtonColor"));
+            ui->scrollAreaTheme->findChildren<QPushButton *>(QRegularExpression("^pushButtonColor"));
 
     for (auto button : buttons) {
         QColor color = evalColor( button->property("VALUE").toString(), m_theme );
@@ -357,20 +359,20 @@ void ConfigTabAppearance::updateFontButtons()
     const int iconExtent = pointsToPixels(12);
     const QSize iconSize(iconExtent * 2, iconExtent);
 
-    const auto ratio = ui->scrollAreaTheme->devicePixelRatio();
+    const auto ratio = pixelRatio(ui->scrollAreaTheme);
     QPixmap pix(iconSize * ratio);
     pix.setDevicePixelRatio(ratio);
 
     const QRect textRect( QPoint(0, 0), iconSize );
 
-    const QRegExp re("^pushButton(.*)Font$");
+    const QRegularExpression re("^pushButton(.*)Font$");
     QList<QPushButton *> buttons = ui->scrollAreaTheme->findChildren<QPushButton *>(re);
 
     for (auto button : buttons) {
-        if ( re.indexIn(button->objectName()) == -1 )
-            Q_ASSERT(false);
+        const auto m = re.match(button->objectName());
+        Q_ASSERT(m.hasMatch());
 
-        const QString colorButtonName = "pushButtonColor" + re.cap(1);
+        const QString colorButtonName = "pushButtonColor" + m.captured(1);
 
         QPushButton *buttonFg = ui->scrollAreaTheme->findChild<QPushButton *>(colorButtonName + "Fg");
         QColor colorFg = (buttonFg == nullptr) ? m_theme.color("fg")
@@ -489,7 +491,7 @@ void ConfigTabAppearance::decoratePreview()
     model->setData(index, dataMap, contentType::updateData);
 
     // Highlight found text but don't filter out any items.
-    c->filterItems( QRegExp(QString("|") + searchFor, Qt::CaseInsensitive) );
+    c->filterItems( QRegularExpression(QString("|") + searchFor, QRegularExpression::CaseInsensitiveOption) );
 
     QAction *act;
 
