@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -28,7 +28,7 @@ class QWidget;
 /**
  * Opens native file dialog (unlike QFileDialog).
  */
-class FileDialog : public QObject
+class FileDialog final : public QObject
 {
     Q_OBJECT
 public:
