@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -29,7 +29,7 @@ namespace {
 
 const int maxCompletionItems = 100;
 
-class CompletionModel : public QAbstractListModel
+class CompletionModel final : public QAbstractListModel
 {
 public:
     explicit CompletionModel(QObject *parent)
