@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -26,7 +26,7 @@ class QModelIndex;
 
 class IconListWidget;
 
-class IconSelectDialog : public QDialog
+class IconSelectDialog final : public QDialog
 {
     Q_OBJECT
 
