@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -24,9 +24,8 @@
 
 class QString;
 
-class IconWidget : public QWidget
+class IconWidget final : public QWidget
 {
-    Q_OBJECT
 public:
     explicit IconWidget(int icon, QWidget *parent = nullptr);
 
