@@ -313,6 +313,8 @@ public:
     /** Open action dialog with input data from selected items. */
     void openActionDialog();
 
+    void showItemContent();
+
     /** Open preferences dialog. */
     void openPreferences();
 
@@ -454,7 +456,7 @@ private:
     void tabBarMenuRequested(QPoint pos, int tab);
     void tabTreeMenuRequested(QPoint pos, const QString &groupPath);
     void tabCloseRequested(int tab);
-    void onFilterChanged(const QRegExp &re);
+    void onFilterChanged(const QRegularExpression &re);
 
     void raiseLastWindowAfterMenuClosed();
 
@@ -690,7 +692,6 @@ private:
     bool m_activatingItem = false;
 
     QVector< QPointer<QAction> > m_actions;
-    QPointer<QAction> m_showHideAction;
     MenuItems m_menuItems;
 
     QList<PersistentDisplayItem> m_displayItemList;
