@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -29,7 +29,7 @@ class QLabel;
 class QGridLayout;
 class QHBoxLayout;
 
-class Notification : public QWidget
+class Notification final : public QWidget
 {
     Q_OBJECT
 
