@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -33,7 +33,7 @@ class QPixmap;
 class QPoint;
 class QWidget;
 
-class NotificationDaemon : public QObject
+class NotificationDaemon final : public QObject
 {
     Q_OBJECT
 public:
