@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -30,7 +30,7 @@ namespace Ui {
 class PluginWidget;
 }
 
-class PluginWidget : public QWidget
+class PluginWidget final : public QWidget
 {
     Q_OBJECT
 
