@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -30,7 +30,7 @@ class QPushButton;
 /**
  * Widget with buttons for defining shortcuts and single button for adding shortcuts.
  */
-class ShortcutButton : public QWidget
+class ShortcutButton final : public QWidget
 {
     Q_OBJECT
 public:
