@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -26,10 +26,8 @@ namespace Ui {
 class ShortcutDialog;
 }
 
-class ShortcutDialog : public QDialog
+class ShortcutDialog final : public QDialog
 {
-    Q_OBJECT
-
 public:
     explicit ShortcutDialog(QWidget *parent = nullptr);
     ~ShortcutDialog();
