@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -50,7 +50,7 @@ struct MenuAction {
 /**
  * Widget with list of modifiable shortcuts and filter field.
  */
-class ShortcutsWidget : public QWidget
+class ShortcutsWidget final : public QWidget
 {
     Q_OBJECT
 
