@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -29,7 +29,7 @@ class QModelIndex;
 class QMouseEvent;
 class QPoint;
 
-class TabBar : public QTabBar, public TabsWidgetInterface
+class TabBar final : public QTabBar, public TabsWidgetInterface
 {
     Q_OBJECT
 
