@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -33,7 +33,7 @@ class QStackedWidget;
 class QToolBar;
 class TabsWidgetInterface;
 
-class TabWidget : public QWidget
+class TabWidget final : public QWidget
 {
     Q_OBJECT
 
