@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -23,10 +23,8 @@
 #include <QWidget>
 #include <QTimer>
 
-class WindowGeometryGuard : public QObject
+class WindowGeometryGuard final : public QObject
 {
-    Q_OBJECT
-
 public:
     static void create(QWidget *window);
 
