@@ -23,7 +23,7 @@
 #include "item/itemwidget.h"
 
 #include <QPersistentModelIndex>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextEdit>
 
 #include <memory>
@@ -56,11 +56,11 @@ public:
 
     QModelIndex index() const { return m_index; }
 
-    void search(const QRegExp &re);
+    void search(const QRegularExpression &re);
 
-    void findNext(const QRegExp &re);
+    void findNext();
 
-    void findPrevious(const QRegExp &re);
+    void findPrevious();
 
     QWidget *createToolbar(QWidget *parent);
 
@@ -89,11 +89,12 @@ private:
     void setBackground();
     void eraseStyle();
 
-    void search(const QRegExp &re, bool backwards);
+    void search(bool backwards);
 
     QPersistentModelIndex m_index;
     bool m_saveOnReturnKey;
     bool m_editNotes;
+    QRegularExpression m_re;
 };
 
 #endif // ITEMEDITORWIDGET_H
