@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -53,24 +53,14 @@ bool createItemDirectory()
 }
 
 void printItemFileError(
-        const QString &action, const QString &id, const QString &fileName, const QFile &file)
+        const QString &action, const QString &id, const QFile &file)
 {
-    log( QString("Cannot %1 tab %2 to %3 (%4)!")
-         .arg(action,
-              quoteString(id),
-              quoteString(fileName),
-              file.errorString())
-         , LogError );
-}
-
-void printSaveItemFileError(const QString &id, const QString &fileName, const QFile &file)
-{
-    printItemFileError("save", id, fileName, file);
-}
-
-void printLoadItemFileError(const QString &id, const QString &fileName, const QFile &file)
-{
-    printItemFileError("load", id, fileName, file);
+    log( QString("Tab %1: Failed to %2, file %3: %4").arg(
+             quoteString(id),
+             action,
+             quoteString(file.fileName()),
+             file.errorString()
+         ), LogError );
 }
 
 ItemSaverPtr loadItems(
@@ -81,7 +71,7 @@ ItemSaverPtr loadItems(
 
     QFile tabFile(tabFileName);
     if ( !tabFile.open(QIODevice::ReadOnly) ) {
-        printLoadItemFileError(tabName, tabFileName, tabFile);
+        printItemFileError("load tab", tabName, tabFile);
         return nullptr;
     }
 
@@ -114,22 +104,25 @@ ItemSaverPtr loadItems(const QString &tabName, QAbstractItemModel &model, ItemFa
 
     const QString tabFileName = itemFileName(tabName);
 
+    ItemSaverPtr saver;
+
     // If tab file doesn't exist, try to restore data from temporary file.
     if ( !QFile::exists(tabFileName) ) {
         QFile tmpFile(tabFileName + ".tmp");
         if ( tmpFile.exists() ) {
-            log( QString("Tab \"%1\": Restoring items (previous save failed)"), LogWarning );
-            if ( !tmpFile.rename(tabFileName) ) {
-                printLoadItemFileError(tabName, tabFileName, tmpFile);
-                return nullptr;
-            }
+            log( QString("Tab \"%1\": Restoring items (previous save failed)").arg(tabName), LogWarning );
+
+            saver = loadItems(tabName, tmpFile.fileName(), model, itemFactory, maxItems);
+            if ( saver && !tmpFile.rename(tabFileName) )
+                printItemFileError("overwrite original file", tabName, tmpFile);
         }
     }
 
-    // Load file with items or create new file.
-    auto saver = QFile::exists(tabFileName)
-            ? loadItems(tabName, tabFileName, model, itemFactory, maxItems)
-            : createTab(tabName, model, itemFactory, maxItems);
+    if (!saver) {
+        saver = QFile::exists(tabFileName)
+                ? loadItems(tabName, tabFileName, model, itemFactory, maxItems)
+                : createTab(tabName, model, itemFactory, maxItems);
+    }
 
     if (!saver) {
         model.removeRows(0, model.rowCount());
@@ -151,32 +144,35 @@ bool saveItems(const QString &tabName, const QAbstractItemModel &model, const It
     // Save to temp file.
     QFile tmpFile( tabFileName + ".tmp" );
     if ( !tmpFile.open(QIODevice::WriteOnly) ) {
-        printSaveItemFileError(tabName, tabFileName, tmpFile);
+        printItemFileError("save tab (open temporary file)", tabName, tmpFile);
         return false;
     }
 
     COPYQ_LOG( QString("Tab \"%1\": Saving %2 items").arg(tabName).arg(model.rowCount()) );
 
     if ( !saver->saveItems(tabName, model, &tmpFile) ) {
-        COPYQ_LOG( QString("Tab \"%1\": Failed to save items!").arg(tabName) );
+        printItemFileError("save tab (save items to temporary file)", tabName, tmpFile);
         return false;
     }
 
     // 1. Safely flush all data to temporary file.
-    tmpFile.flush();
+    if ( !tmpFile.flush() ) {
+        printItemFileError("save tab (flush temporary file)", tabName, tmpFile);
+        return false;
+    }
 
     // 2. Remove old tab file.
     {
         QFile oldTabFile(tabFileName);
         if (oldTabFile.exists() && !oldTabFile.remove()) {
-            printSaveItemFileError(tabName, tabFileName, oldTabFile);
+            printItemFileError("save tab (remove file)", tabName, oldTabFile);
             return false;
         }
     }
 
     // 3. Overwrite previous file.
     if ( !tmpFile.rename(tabFileName) ) {
-        printSaveItemFileError(tabName, tabFileName, tmpFile);
+        printItemFileError("save tab (overwrite original file)", tabName, tmpFile);
         return false;
     }
 
@@ -192,16 +188,22 @@ void removeItems(const QString &tabName)
     QFile::remove(tabFileName + ".tmp");
 }
 
-void moveItems(const QString &oldId, const QString &newId)
+bool moveItems(const QString &oldId, const QString &newId)
 {
     const QString oldFileName = itemFileName(oldId);
     const QString newFileName = itemFileName(newId);
 
     if ( oldFileName != newFileName && QFile::copy(oldFileName, newFileName) ) {
         QFile::remove(oldFileName);
-    } else {
-        COPYQ_LOG( QString("Failed to move items from \"%1\" (tab \"%2\") to \"%3\" (tab \"%4\")")
-                   .arg(oldFileName, oldId,
-                        newFileName, newId) );
+        return true;
     }
+
+    log( QString("Failed to move items from \"%1\" (tab \"%2\") to \"%3\" (tab \"%4\")").arg(
+             oldFileName,
+             oldId,
+             newFileName,
+             newId
+       ), LogError );
+
+    return false;
 }
