@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -38,7 +38,7 @@ void removeItems(const QString &tabName //!< See ClipboardBrowser::getID().
         );
 
 /** Move configuration file for items. */
-void moveItems(
+bool moveItems(
         const QString &oldId, //!< See ClipboardBrowser::getID().
         const QString &newId //!< See ClipboardBrowser::getID().
         );
