@@ -17,7 +17,7 @@ public:
     void setTagged(bool tagged) override;
 
 protected:
-    void highlight(const QRegExp &re, const QFont &highlightFont,
+    void highlight(const QRegularExpression &re, const QFont &highlightFont,
                    const QPalette &highlightPalette) override;
 
     ItemWidget *childItem() const { return m_childItem.get(); }
