@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -41,12 +41,10 @@ QClipboard::Mode modeToQClipboardMode(ClipboardMode mode)
 
 } // namespace
 
-DummyClipboard::DummyClipboard(bool connectClipboardSignal)
+void DummyClipboard::startMonitoring(const QStringList &)
 {
-    if (connectClipboardSignal) {
-        connect(QApplication::clipboard(), &QClipboard::changed,
-                this, &DummyClipboard::onClipboardChanged);
-    }
+    connect(QApplication::clipboard(), &QClipboard::changed,
+            this, &DummyClipboard::onClipboardChanged);
 }
 
 QVariantMap DummyClipboard::data(ClipboardMode mode, const QStringList &formats) const
