@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -25,7 +25,7 @@
 /**
  * Class for doing conversions of URLs between OS X UTIs and "normal" mimeTypes.
  */
-class UrlPasteboardMime : public QMacPasteboardMime {
+class UrlPasteboardMime final : public QMacPasteboardMime {
 public:
     //! Create an instance of UrlPasteboardMime which will try to convert to/from the given UTI.
     UrlPasteboardMime(const QString &urlUti);
