@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -24,17 +24,15 @@
 
 #include <qt_windows.h>
 
-class WinPlatformClipboard : public DummyClipboard
+class WinPlatformClipboard final : public DummyClipboard
 {
-    Q_OBJECT
 public:
-    WinPlatformClipboard();
-
-private slots:
-    void checkClipboard();
+    void startMonitoring(const QStringList &) override;
 
 private:
-    DWORD m_lastClipboardSequenceNumber;
+    void checkClipboard();
+
+    DWORD m_lastClipboardSequenceNumber = -1;
 };
 
 #endif // WINPLATFORMCLIPBOARD_H
