@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -27,7 +27,7 @@
 #endif
 #include <qt_windows.h>
 
-class WinPlatformWindow : public PlatformWindow
+class WinPlatformWindow final : public PlatformWindow
 {
 public:
     explicit WinPlatformWindow(HWND window);
