@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -28,7 +28,7 @@
 
 class QWidget;
 
-class X11PlatformWindow : public PlatformWindow
+class X11PlatformWindow final : public PlatformWindow
 {
 public:
     explicit X11PlatformWindow();
