@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -29,7 +29,7 @@
 class QScriptContext;
 class QScriptEngine;
 
-class DirClass : public ScriptableClass<DirWrapper, DirPrototype>
+class DirClass final : public ScriptableClass<DirWrapper, DirPrototype>
 {
     Q_OBJECT
 public:
