@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -30,7 +30,7 @@ class QFile;
 class QScriptContext;
 class QScriptEngine;
 
-class FileClass : public ScriptableClass<QFile, FilePrototype>
+class FileClass final : public ScriptableClass<QFile, FilePrototype>
 {
     Q_OBJECT
 public:
