@@ -53,7 +53,7 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QPoint>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QScriptContext>
 #include <QScriptEngine>
 #include <QScriptValueIterator>
@@ -284,17 +284,20 @@ struct ScriptValueFactory<QString> {
 };
 
 template <>
-struct ScriptValueFactory<QRegExp> {
-    static QScriptValue toScriptValue(const QRegExp &re, const Scriptable *scriptable)
+struct ScriptValueFactory<QRegularExpression> {
+    static QScriptValue toScriptValue(const QRegularExpression &re, const Scriptable *scriptable)
     {
-        return scriptable->engine()->newRegExp(re);
+        return scriptable->engine()->newVariant(re);
     }
 
-    static QRegExp fromScriptValue(const QScriptValue &value, const Scriptable *scriptable)
+    static QRegularExpression fromScriptValue(const QScriptValue &value, const Scriptable *scriptable)
     {
-        return value.isRegExp()
-                ? value.toRegExp()
-                : QRegExp( toString(value, scriptable) );
+        if (value.isVariant()) {
+            const auto variant = value.toVariant();
+            return variant.toRegularExpression();
+        }
+
+        return QRegularExpression( toString(value, scriptable) );
     }
 };
 
@@ -382,8 +385,9 @@ struct ScriptValueFactory<QVariant> {
         if (variant.type() == QVariant::Char)
             return ::toScriptValue(variant.toString(), scriptable);
 
-        if (variant.type() == QVariant::RegExp)
-            return ::toScriptValue(variant.toRegExp(), scriptable);
+        Q_ASSERT(variant.type() != QVariant::RegExp);
+        if (variant.type() == QVariant::RegularExpression)
+            return ::toScriptValue(variant.toRegularExpression(), scriptable);
 
         if (variant.canConvert<QVariantList>())
             return ::toScriptValue(variant.value<QVariantList>(), scriptable);
@@ -496,13 +500,13 @@ QString parseCommandLineArgument(const QString &arg)
     return result;
 }
 
-bool matchData(const QRegExp &re, const QVariantMap &data, const QString &format)
+bool matchData(const QRegularExpression &re, const QVariantMap &data, const QString &format)
 {
-    if ( re.isEmpty() )
+    if ( re.pattern().isEmpty() )
         return true;
 
     const QString text = getTextData(data, format);
-    return re.indexIn(text) != -1;
+    return text.contains(re);
 }
 
 bool isInternalDataFormat(const QString &format)
@@ -2619,10 +2623,16 @@ void Scriptable::onMonitorClipboardUnchanged(const QVariantMap &data)
     m_proxy->runInternalAction(data, "copyq onClipboardUnchanged");
 }
 
-void Scriptable::onSynchronizeSelection(ClipboardMode sourceMode, const QString &text, uint targetTextHash)
+void Scriptable::onSynchronizeSelection(ClipboardMode sourceMode, const QString &text)
 {
 #ifdef HAS_MOUSE_SELECTIONS
     auto data = createDataMap(mimeText, text);
+    const auto targetMode = sourceMode == ClipboardMode::Clipboard
+        ? QClipboard::Selection
+        : QClipboard::Clipboard;
+    auto clipboard = QGuiApplication::clipboard();
+    const auto targetText = clipboard->text(targetMode);
+    const auto targetTextHash = qHash(targetText);
     data[COPYQ_MIME_PREFIX "target-text-hash"] = QByteArray::number(targetTextHash);
     const auto command = sourceMode == ClipboardMode::Clipboard
         ? "copyq --clipboard-access synchronizeToSelection"
@@ -2631,7 +2641,6 @@ void Scriptable::onSynchronizeSelection(ClipboardMode sourceMode, const QString
 #else
     Q_UNUSED(text);
     Q_UNUSED(sourceMode);
-    Q_UNUSED(targetTextHash);
 #endif
 }
 
@@ -2742,7 +2751,7 @@ QString Scriptable::processUncaughtException(const QString &cmd)
         return QString();
 
     const auto exceptionName = m_engine->uncaughtException().toString()
-            .remove(QRegExp("^Error: "))
+            .remove(QRegularExpression("^Error: "))
             .trimmed();
 
     auto backtrace = m_engine->uncaughtExceptionBacktrace();
@@ -3081,7 +3090,7 @@ bool Scriptable::runCommands(CommandType::CommandType type)
 
             // FIXME: Handle automatic and display command output.
             //action.setOutputFormat(command.output);
-            //action.setItemSeparator(QRegExp(command.sep));
+            //action.setItemSeparator(QRegularExpression(command.sep));
             //action.setOutputTab(command.outputTab);
 
             if ( !runAction(&action) && canContinue() ) {
