@@ -39,6 +39,8 @@
 #include "gui/icons.h"
 #include "gui/mainwindow.h"
 #include "gui/notification.h"
+#include "gui/pixelratio.h"
+#include "gui/screen.h"
 #include "gui/tabicons.h"
 #include "gui/windowgeometryguard.h"
 #include "item/serialize.h"
@@ -57,7 +59,6 @@
 #include <QCursor>
 #include <QDateTimeEdit>
 #include <QDesktopServices>
-#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QFile>
 #include <QFileInfo>
@@ -1257,7 +1258,7 @@ QString ScriptableProxy::browserRemoveRows(const QString &tabName, QVector<int>
     if (!c)
         return QString("Invalid tab");
 
-    qSort( rows.begin(), rows.end(), qGreater<int>() );
+    std::sort( rows.begin(), rows.end(), std::greater<int>() );
 
     QModelIndexList indexes;
     indexes.reserve(rows.size());
@@ -1625,7 +1626,7 @@ QString ScriptableProxy::testSelected()
     selectedRows.reserve( selectedIndexes.size() );
     for (const auto &index : selectedIndexes)
         selectedRows.append(index.row());
-    qSort(selectedRows);
+    std::sort( selectedRows.begin(), selectedRows.end() );
 
     for (int row : selectedRows)
         result.append(QString::number(row));
@@ -1803,7 +1804,7 @@ QByteArray ScriptableProxy::screenshot(const QString &format, const QString &scr
     QScreen *selectedScreen = nullptr;
     if ( screenName.isEmpty() ) {
         const auto mousePosition = QCursor::pos();
-        const int screenNumber = QApplication::desktop()->screenNumber(mousePosition);
+        const int screenNumber = ::screenNumberAt(mousePosition);
         if (screenNumber != -1)
             selectedScreen = QGuiApplication::screens().value(screenNumber);
     } else {
@@ -1834,7 +1835,7 @@ QByteArray ScriptableProxy::screenshot(const QString &format, const QString &scr
             QCoreApplication::processEvents();
         const auto rect = rectWidget.selectionRect;
         if ( rect.isValid() ) {
-            const auto ratio = pixmap.devicePixelRatio();
+            const auto ratio = pixelRatio(&pixmap);
             const QRect rect2( rect.topLeft() * ratio, rect.size() * ratio );
             pixmap = pixmap.copy(rect2);
         }
@@ -2031,7 +2032,7 @@ void ScriptableProxy::showDataNotification(const QVariantMap &data)
     const int width = pointsToPixels(maximumWidthPoints) - 16 - 8;
 
     const QStringList formats = data.keys();
-    const int imageIndex = formats.indexOf(QRegExp("^image/.*"));
+    const int imageIndex = formats.indexOf(QRegularExpression("^image/.*"));
     const QFont &font = notification->font();
     const bool isHidden = data.contains(mimeHidden);
 
