@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -24,7 +24,7 @@
 
 class QTemporaryFile;
 
-class TemporaryFilePrototype : public FilePrototype
+class TemporaryFilePrototype final : public FilePrototype
 {
     Q_OBJECT
 public:
