@@ -21,7 +21,6 @@
 #define TESTINTERFACE_H
 
 #include "common/clipboardmode.h"
-#include "common/sleeptimer.h"
 
 #include <QStringList>
 
@@ -109,6 +108,8 @@ public:
     /// Set environment variable for test.
     virtual void setEnv(const QString &name, const QString &value) = 0;
 
+    virtual bool writeOutErrors(const QByteArray &errors) = 0;
+
     TestInterface(const TestInterface &) = delete;
     TestInterface &operator=(const TestInterface &) = delete;
 };
