@@ -4,14 +4,9 @@ set -e
 distro=${1:-xenial}
 version="$(git describe|sed 's/^v//;s/-/./;s/-/~/')~$distro"
 
-if [ "$distro" == "trusty" ]; then
-    cp debian/control{-qt4,}
-    cp debian/rules{-qt4,}
-else
-    git checkout HEAD debian/control debian/rules
-    sed -i 's/debhelper .*,/debhelper (>= 9),/' 'debian/control'
-    sed -i 's/Standards-Version:.*/Standards-Version: 3.9.7/' 'debian/control'
-fi
+git checkout HEAD debian/control debian/rules
+sed -i 's/debhelper .*,/debhelper (>= 9),/' 'debian/control'
+sed -i 's/Standards-Version:.*/Standards-Version: 3.9.7/' 'debian/control'
 
 git checkout HEAD debian/changelog
 
