@@ -6,7 +6,7 @@ make_icons()
     input_icon=$1
     output_basename=$2
 
-    for extent in 16 22 24 32 48 64 128; do
+    for extent in 16 22 24 32 48 64 128 256 512 1024; do
         size="${extent}x${extent}"
         output="${output_basename}_$size.png"
         echo "Converting $input_icon -> $output"
@@ -16,5 +16,5 @@ make_icons()
 }
 
 cd src/images
-make_icons icon.svg icon-normal
-make_icons icon-running.svg icon-busy
+make_icons icon.svg icon
+make_icons icon-busy.svg icon-busy
