@@ -6,10 +6,12 @@ exclude_files=(
     qxt
     /usr
     plugins/itemfakevim/fakevim
+    src/gui/fix_icon_id.h
 )
 
 # Exclude generated files.
 exclude_regexs=(
+    'build/.*'
     '.*/moc_.*'
     '.*\.moc$'
     '.*_automoc\..*'
